---
# Standard Scrivener + Pandoc[omatic] Project YAML metadata
# IMPORTANT: YAML configuration files use SPACES for indentation to 
# define structure, remember to straighten any smart quotes, and don't
# capitalise metadata keys like "author" or "title", they must be 
# lowercase! Use "Show Invisibles" in Scrivener to see spaces.
section: Original Research | 研究論文
title: Beyond the Character Sheet
subtitle: Character Keepers as Digital Play Aids in the Contemporary Indie TRPG Community
author:
  - name: Hermann, Adrian | エイドリアン ヘルマン
    affiliation: 1
  - name: Reininghaus, Gerrit | ゲリット ライニクハウス
    affiliation: 2
#    equal_contributor: true
#    correspondence: xx
institute:
  - ^1^: University of Bonn | ボン大学
  - ^2^: Independent Scholar | 独立研究者
keywords:
  - character sheet
  - character keeper
  - indie TRPGs
  - online play
  - play aids
lang: en
#citation_en: Hermann, Adrian and Gerrit Reininghaus. 2021. “Beyond the Character Sheet: ‘Character Keepers‘ as Digital Play Aids in the Contemporary Indie TRPG Community.” Japanese Journal of Analog Role-Playing Game Studies, 2: 31-50.
#citation_jp: 山本 真妃沙. 2021.「オンラインで実施されるゲーム型の図書館ガイダンスの制作と実践」『RPG学研究』2号: 
doi: 10.14989/jarps_2_31
#compiled: 2024/07/15
#date: Monday, July 15, 2024
#comments: ""
# Select which templates pandocomatic will use,
# you can enter overrides to the templates here as well
pandocomatic_:
  use-template:
#    - docx-refs
    - html-refs
#    - pdf-refs
---

# Abstract #

::: {custom-style="Abstract"} :::
<span class="paranum">[0.1]</span>This article explores a central aspect of contemporary online play culture in some parts of the indie TRPG community: the "character keeper" as an emphatically 'digital' character sheet, most often realized as a Google Sheets spreadsheet. Rather than simply functioning as digital equivalents of paper character records, keepers serve as shared sheets, allowing all players to refer to the information on all player characters simultaneously. They take advantage of the programming interface of Google Sheets to provide automated functions like drop-down selections for character options or real-time calculation of stats. In many cases, keepers also include tabs for tracking shared session and campaign notes as well as scenario and game state information for the GM and include a lot of the reference information needed to play the game. Finally, they integrate supplementary safety tools that facilitate play and provide links to other accessories used during online play, like digital dice rollers or additional visualization tools. Throughout the article, we discuss the general role of characters sheets in TRPGs and analyze character keepers' particular characteristics and the pragmatics of their use. Subsequently, we highlight elements of a short history of this format, describe some historical and contemporary examples, and close with a systematic exploration of contemporary player and designer theorizing on this topic.  

<span class="paranum">[0.2]</span> Keywords: Character sheet, character keeper, indie TRPGs, online play, play aids  
:::


# 要約 #

::: {custom-style="Abstract"} :::
<span class="paranum">[0.3]</span> 本稿では，同人TRPGコミュニティの一部で見られる，現在のオンラインプレイ文化の中心的な側面である，Google Sheets スプレッドシートとして実現されることが多い「デジタル」キャラクターシートとしての「キャラクターキーパー」について考察する．キーパーは，単に紙のキャラクター記録のデジタル版として機能するのではなく，すべてのプレイヤーがすべてのプレイヤーキャラクターの情報を同時に参照できる，共有シートとして機能している．また，Google Sheetsのプログラミングインターフェイスを利用して，キャラクターのオプションをドロップダウンで選択したり，ステータスをリアルタイムに計算したりするなどの自動化機能を備えている．多くの場合，キーパーには，共有セッションやキャンペーンのメモ，GMのためのシナリオやゲームステートの情報などを記録するタブが含まれており，ゲームをプレイするために必要な多くの参考情報が含まれている．最後に，ゲームを円滑に進めるための補助的な安全ツールを統合し，デジタルサイコロや追加の視覚化ツールなど，オンラインプレイで使用する他のアクセサリーへのリンクを提供している．本稿では，TRPGにおけるキャラクターシートの一般的な役割を説明した上で，キャラクターキーパーの特徴とその使用方法を分析している．続いて，このフォーマットの短い歴史の要素を紹介し，いくつかの歴史的および現代的な例を説明し，最後に，このトピックに関する現在のプレイヤーとデザイナーの理論化を体系的に探る．  

<span class="paranum">[0.4]</span> キーワード：キャラクターシート、キャラクターキーパー、同人TRPG、オンラインプレイ、プレイ・エイド  
:::


# 1. Introduction #

<span class="paranum">[1.1]</span> In most role-playing games, play begins with character creation. In fact, the creation of characters should itself be considered part of playing the respective game [@torner2017b]. One could even argue that writing down persistent traits for a unique character in the game was *the* most crucial step that allowed role-playing to emerge from wargaming in the early 1970s. Therefore, it is not surprising that Peterson in *Playing at the World* describes role-playing games as being created out of a combination of a new understanding of setting, system, and *character* [-@peterson2012a, 81-457]. Only rarely do players -- at least in tabletop role-playing games (TRPGs) -- not have some form of a written record of their character in front of them during a gaming session.  


<span class="paranum">[1.2]</span> By looking at the development of character records, one can trace the development of (T)RPGs in general and the history of their precursors [@peterson2012a, 289-90, 359-71; -@peterson2013; -@peterson2014a; @dhboggs2017]. As a sign of the "individuation" [@peterson2012a, 359] of player characters, such records are part of the slow 'invention' of role-playing games in the 1960s and 1970s, even though this invention does not directly coincide with the production of officially designed character sheets. The original edition of *Dungeons & Dragons* (*D&D*) [@gygax.arneson1974] did not include pre-printed sheets. However, such sheets were among the first content published in initial fanzines [@peterson2013]. As some of the earliest accessories produced for D&D, character sheets were also the topic of the first copyright debates regarding the game [@peterson2012a, 551-57].  


<span class="paranum">[1.3]</span> In this article, we want to explore in detail a contemporary version of the character record that has become a central part of online play culture in some parts of the indie TRPG community: the *character keeper*. As a shared and emphatically 'digital' character sheet, such character keepers are most often realized in the form of a Google Sheets spreadsheet.[^fn1]  


# 2. What Is a Character Sheet? #

<span class="paranum">[2.1]</span> Various contributors to role-playing game studies [@morningstar2016; @torner2017b] have noted the importance of the character sheet as one of the central pieces of physical "role playing materials" [@bienia2016]. Next to maybe only dice and maps, character sheets can be considered a crucial, if not the most essential, "player-facing" resource [@morningstar2016, 127] in TRPGs. As the primary record of player investment, character sheets "constitute just as much of a role-playing game's 'text' as the session itself" [@torner2017b]. In addition to looking at the mostly transitory role-playing game session [@padol2007; @jara2013, 40] -- at least until the recent rise of recorded actual plays [@jones2021] and despite some longer traditions of detailed documentation of sessions like the Japanese "replay" [@kamm2019b, 628-30] --, analyzing character sheets helps us understand "role-playing games as media" [@torner2017b].  


<span class="paranum">[2.2]</span> With Konzack, one could say that character sheets are therefore much more than a "paratext" [@jara2013] and arguably are "involved in the whole process and every aspect of TRPG[s]" as a crucial element that keeps the "textual machine" [@konzack2013, 87] of the game session running. In the sense proposed by Hammer [-@hammer2007, 70-71], they "function as primary, secondary and tertiary texts"[^fn2] [@konzack2013, 87] and represent "the central document from which the player relates to role-playing a character as regards to rules, setting, situation, and performance" [@konzack2013, 87].  


<span class="paranum">[2.3]</span> Nevertheless, not much has been written academically about character sheets. Even the foundational *Role-Playing Game Studies* handbook [@zagal.deterding2018] contains little in-depth reflection on the material aspects of dice, maps, and character sheets, despite their foundational importance for the practice of tabletop role-playing games [an exception is @bienia2018]. In both popular theorizing [see @torner2018a] and academic commentary, the most interest so far has been paid to the historical evolution of character sheets, in particular regarding the different editions of *D&D* [see, e.g., @peterson2012a, 365-71; @peterson2013]. Some notable exceptions to this lack of attention are Rients [-@rients2014] on intertextuality and margin notes, Morningstar [-@morningstar2016] on visual design, as well as Bienia [-@bienia2016], Banks, Bowman, and Wasserman [-@banks.etal2018], and Webber [-@webber2019] on materiality.  


<span class="paranum">[2.4]</span> A character sheet is traditionally a piece of paper collecting information about a character in a role-playing game. It is often provided as a pre-made printed sheet, template to be photocopied, or downloadable PDF. It serves as a "record of static and dynamic character traits" [@bienia2016, 143)]and "defines the character to the participants" [@konzack2013, 86], in particular to the character's player and the game master. We will see how this second function is extended to all players simultaneously in the case of digital character keepers. Torner draws our attention to how character sheets, as "non-diegetic texts," support the diegesis "by helping a player perform as a character within it" through making available both mechanical information and "deliberate emotional propositions" which "pull the player into the role" [@torner2017b]. In this sense, they are "documents that seek instantiation and/or confirmation in the actual play" [@torner2017b; see also @konzack2013, 93].  


<span class="paranum">[2.5]</span> Character sheets normally collect a large variety of information like a basic character description (name, physical features), skills, powers, and experience, combat skills, defensive mechanisms, equipment, companions, money, psychology and flaws, information on the character's background, and possibly pictures and notes [@konzack2013, 89]. In addition, sheets often display "[n]on character material" like decorative art or the name of the game [@konzack2013, 89]. Morningstar [-@morningstar2016, 129] has proposed to distinguish between "static", "stable", and "volatile" information recorded on a sheet. The first normally does not change (a character's name, their appearance), the second is rarely adjusted, like once per game session (level, new skills, or moves), while the third is frequently updated (hit points, equipment, or stress indicators).  


<span class="paranum">[2.6]</span> Konzack's concept of "characterology" describes how a character sheet's design influences "how the character is played" [-@konzack2013, 86]. He argues that "character sheets are not neutral, but allow for a certain range of player behavior," encouraging some and discouraging other activities [@konzack2013, 86]. In that sense, the information on the character sheet provides both "quantifiable measures of player-character qualities and player-character scripts for plausible actions and re-actions within the game world" [@konzack2013, 88]. One could say then that the design of a character sheet implements the characterology inherent in a particular game system [@konzack2013, 86, 92]. Since the 1970s, the design of character sheets also expressed a certain tension between universal sheets and specific sheets for particular character types or "classes" [@peterson2013]. In many indie TRPGs published in the 2010s, the "playbook," as a particular style of sheet stemming from *Apocalypse World* [@baker2010a; @baker.baker2016], combines a specific sheet for each character type with the corresponding character options.  


<span class="paranum">[2.7]</span> The information codified on the character sheet also mediates between the agency implied in a particular character's fictional role and their concrete ability to act in the game according to the rules. It can only ever partly represent their potentially relevant traits and "diegetic power" [@hammer.etal2018a, 453] irrespective of whether they are a queen or a peasant in the fiction. In fact, Rients [-@rients2014, 11] argues, on many sheets "there's very little room for detailing the things that make a character really a character", like their relationships to other player characters or NPCs (*non-player characters*) and additional information that players often make use of in play [see also @mackay2001, 99].  


<span class="paranum">[2.8]</span> In sum, character sheets can be considered both a necessary and a defining feature of most TRPGs [@zagal.deterding2018a, 27]. While a wide variety of "supporting props" [@zagal.deterding2018a, 31] are used in playing these games -- like miniatures, battle maps, or 3D-terrain --, and most use dice, very few TRPGs, if any, can do without some form of character record [@bienia2016, 128]. As Torner writes, the "fluidity between written and performed character text is, in fact, specific to role-playing games as a medium" [@torner2017b]. Filling out a character sheet [as a central stage of "character evolution," @bowman.schrier2018, 403], or being handed a pre-filled character sheet, can sometimes be the only prerequisite to play [@rients2014, 9], as just-in-time explanations by other players can replace almost all knowledge of the rules.  


<span class="paranum">[2.9]</span> If the innovation of TRPGs was that they provided a "system for simulating a person" [@peterson2013, 367], character sheets are what supports this "individuation" [@peterson2013, 366] that forms the basis of play. Playing a single character representing the player in the fictional world still seems to be the most popular way TRPGs are designed and played [see also @montola2009, 24]. Thus, the character sheet can be understood as the primary *interface* (together with dice) between the players and the fictional world: it serves as both user *interface* and *controller* for the character of an individual player.  


<span class="paranum">[2.10]</span> One way of theorizing the character sheet, then, would be to understand it as both a "systemic" and a "compound element," drawing on the theory of game elements proposed by Järvinen [-@jarvinen2009]. He understands the former as "the formal parts of a system" and the latter as "facilitators of the interaction between the systemic and behavioural elements" that also govern this interaction [@jarvinen2009, 29]. Behavioral elements are the players themselves and the context in which a particular game is played. As a systemic element, the character sheet could be understood as a *component*, as an object that the player manipulates during the game. Contrastingly, as a compound element, the character sheet contains *information* and serves as an *interface* for the player to interact with the game system. It fulfills this role by creating connections between different game elements [@jarvinen2009, 87-88]. "Information" as the "fuel of meaning" provides connections between game elements and can be distinguished regarding facts about events, agents, objects, and system [@jarvinen2009, 71]. Concerning character sheets, the question of information management and the distinction between hidden and public information is relevant, as traditionally, character information was seen as somewhat private to the particular character's player.[^fn3] "Interface" as a game element is often considered only regarding video games, where it points to both the physical controllers (keyboard, mouse, or gamepad) and the user interfaces on screen. But more generally, interface(s) can be thought of as the elements which provide "indirect access to the game system when direct access is impossible" [@jarvinen2009, 87]. This applies not only to video game avatars but also to TRPGs, where such direct access to the characters in the individual and shared imagination is not possible. We argue that the character sheet is the most crucial game element that serves as such an interface and allows a player to 'control' their character. In this central role, it should be theorized in conjunction with other aspects of TRPG interfaces like miniatures and dice [see @torner2016, 89].

<span class="paranum">[2.11]</span> While the character sheet's 'connecting' role has been recognized in role-playing game studies, these observations have not been integrated into a more extensive theory. For Rients [-@rients2014, 9], the character sheet is "the one tangible, persistent object that uniquely connects the player to the game activity" [see also @webber2019]. This statement highlights its particular role in contrast to other 'props' that might appear as compound elements in a TRPG session. Serving to focus the player's imagination, most of these "role-playing materials" [@bienia2016] -- like miniatures, handouts, images, and maps -- are shared. The character sheet, however, originally is not. This is also the case because of its concrete materiality. Typically, a paper sheet cannot be read and written on by all players simultaneously and together. This is different not necessarily for all digital character sheets but in particular for digital character keepers. In any case, the sheet of paper used for a particular character is linked to this fictional entity in a "material-ludic relation" [@bienia2016, 144], with the adjusting of entries on the sheet directly translating into potential changes in the imagination [@bienia2016, 145]. A character sheet thus builds, maintains, and records "affective connections" [@webber2019]. It is also often described as taking on the quality of 'being' the character it represents, as in "can you hand me *character name*," pointing to the sheet [@rients2014, 9; @bienia2016, 144]. As a physical object, it defines the "personal area" of the player at the table [@bienia2016, 144-46; @morningstar2016, 130] and, over time, displays "material traces" of its use [@bienia2016, 145]. Serving as both a "representation and a storage medium," it has an archival quality and implies the possibility (though never the certainty) of future play [@webber2019]. Some games even build on and play with these material connections; for example, when in the apocalyptic *Ten Candles* [@dewey2015], the player is instructed to burn the index card representing one of their character's traits after using it. Similarly, during a deadly introductory "funnel" adventure in *Dungeon Crawl Classics* [@goodman.etal2012] – where a player typically plays multiple level-0 characters -- character sheets might be torn up by the game master in an act of finality after the character has died.  


# 3. What Is a Digital Character Keeper? #

<span class="paranum">[3.1]</span> It is, of course, possible to use paper character sheets while playing TRPGs online using audio or video chat (which people did, especially in the early years of online play, and still do). Still, it is not surprising that many players had wanted to (also) store their character information digitally when they started playing online.[^fn4] Although we cannot explore the more extended general history of digital character sheets here, we want to contribute to research on this topic. We focus on one popular and important aspect of contemporary online play culture, especially in the indie TRPG community: digital character keepers,[^fn5] most often created using Google Sheets. The primary purpose of a character keeper is to gather all data about all of a particular game's characters in one place.[^fn6] It becomes the original source of information for online play, i.e., there usually are no additional private sheets, digital or paper. In discussing character keepers in this article, we begin by outlining their characteristics and the pragmatics of their use, followed by elements of a short history of the format, a description of some historical and contemporary examples, and a systematic exploration of contemporary player and designer theorizing on this topic.  


<span class="paranum">[3.2]</span> Google Sheets is an online spreadsheet program (like Microsoft Excel) that allows users to create and edit complex spreadsheets collaboratively and in real-time, mainly through its web application. Each spreadsheet can contain many individual sheets, each represented by a tab at the bottom of the browser window. Cell functions allow for coding complex applications within these documents. Spreadsheets thus combine the simplicity and visual appeal of a table structure with the possibility of backend coding and data management.  


<span class="paranum">[3.3]</span> When used for a character keeper, the Google Sheets spreadsheet file (what in Excel would be called a workbook) regularly contains several individual spreadsheets, either one sheet per character or a single sheet for all characters of a session or campaign (cf. fig. 1). In addition, there often are a variety of other sheets for additional information and the backend data used on the other tab(s). During the game session, players update values and information in real-time. All players and the facilitator have editing access to the keeper.  

![][JARPS_2_charakeepers-1]
![**Fig. 1: Screenshots of a relatively simple 2013 character keeper (empty) for ****_Dungeon World_**** [@latorra.koebel2012] and a highly complex 2021 keeper (in use) for ****_Brindlewood Bay _****[@cordova2020] (character images from Pexels.com, free to use).** *Dungeon World*: [https://docs.google.com/spreadsheets/d/1phUTnmLblFl_fxjCbHiAkR3xmppfzpcNxNC4RDH9b9k/](https://docs.google.com/spreadsheets/d/1phUTnmLblFl_fxjCbHiAkR3xmppfzpcNxNC4RDH9b9k/) (accessed 2021/11/08); *Brindlewood Bay*: [https://arktosaur.us/keepers/brindlewoodbay](https://arktosaur.us/keepers/brindlewoodbay) (accessed 2021/11/08).][JARPS_2_charakeepers-2]
Screenshots of a relatively simple 2013 character keeper (empty) for Dungeon World [@latorra.koebel2012] and a highly complex 2021 keeper (in use) for Brindlewood Bay [@cordova2020] (character images from Pexels.com, free to use).[^fn7]

<span class="paranum">[3.4]</span> A character keeper, then, is like a shared binder of character sheets. Additional tabs contain setting information, rules excerpts, a list of non-player characters, relationship maps, and safety tools. Since all information is usually accessible to all participants in a session (with the possible exception of GM notes), players can look up details that would be mostly inaccessible to them on the other players' character records when using paper sheets. Depending on the play style, this can contribute to smooth gameplay and, even more so, create opportunities for collaborative narration in which players pro-actively address each other's characters' traits and backgrounds. The highly structured spreadsheet format also allows players to easily cross-compare entries (e.g., skill values) or plan an effective strategy in a fight. Many newer keepers also include ways of easily incorporating character portraits (most often using an image the player found online), providing a shared visual reference for the group. Using a character keeper thus can reduce all players' mental load.  


<span class="paranum">[3.5]</span> While they at first glance simply function as digital equivalents of character sheets, character keepers therefore go beyond them in at least the following regards: 1) they serve as shared sheets, allowing all players to refer to the information on all player characters simultaneously -- with many keepers not presenting each player character separately but displaying all of them on a single tab; 2) many sophisticated keepers take advantage of the programming interface of Google Sheets to provide functions like drop-down selections for character options (or even step-by-step guided character creation), real time calculation of stats and other information, or representations of relationships between the player characters; 3) keepers often include tabs for tracking shared session and campaign notes between players and facilitators (lists of NPCs, ongoing mysteries, etc.); 4) scenario and game state information for the facilitator is often also tracked on tabs in the keeper; 5) some (especially newer) keepers include a lot of the reference information needed to play the game (basic rules, skill lists, moves etc.), often making additional reference materials unnecessary; 6) supplementary tools that facilitate play like safety tools are often integrated in a separate tab and also make use of the programming possibilities of Google Sheets; 7) the keeper might also collect links to other accessories used during online play like a digital dice roller or additional visualization tools (Google Drawings or Virtual Table Tops [VTTs] like Roll20).  


<span class="paranum">[3.6]</span> These (and other additional) characteristics of digital character keepers are not simply technical differences that differentiate them from analog character sheets. As we already touched upon above, they directly affect the play culture that has developed around them. Also, in many respects, these features distinguish character keepers from other forms of digital character sheets, both simple character records and sophisticated sheets available within VTTs like Roll20 or Fantasy Grounds. While, for example, automatic calculations are a feature of most character sheets on VTTs, in the end, these are most often still designed as digital 'translations' of paper sheets. In contrast to these 'skeuomorphic' designs that mimic the characteristics of paper sheets in a digital environment,[^fn8] many character keepers help envision what a character record can look like that is designed as digital from the ground up.  


<span class="paranum">[3.7]</span> How are character keepers actually used in online play? Sometimes they are available in the form of a link to a Google Sheets spreadsheet on the website of the designer or publisher of a particular TRPG. But most often, character keepers are 'unofficial' creations provided by GMs and players as links to a 'master' spreadsheet template available from online forums or other community spaces. The online TRPG community "The Gauntlet" curates the most extensive collection.[^fn9] When a group decides to play a game online, the facilitator opens the master template and makes a copy of the keeper, saving it in their own Google Drive, Google's online file storage platform. After changing permissions to allow all people who have the link to edit the spreadsheet, the GM shares this link with players. They then generate and enter their character information either before or during the (first) session. While playing, players keep a browser tab with the character keeper open (often in a prominent and always visible section of their desktop), constantly refer to it for information, update the character record, and use it to keep track of the progression of play.  


<span class="paranum">[3.8]</span> It is important to note that while character keepers have become an important aspect of play culture in a particular section of the indie TRPG community, they only represent one aspect of online play practices. If we transfer Bienia's perspective on the material practice of paper character sheets -- which, for example, includes paying attention to "the position of character sheets on the table" [-@bienia2016, 153] -- to digital character keepers, in studying the online play they help facilitate we would also have to take into account how people organize their digital play spaces more generally. How do players position the browser window with the character keeper in relation to a possible use of audio or video chat software? How many (if any) other browser tabs and additional resources, like PDFs etc., do they use for reference? What difference does a multiple monitor setup make? In addition, one would have to pay attention to how players combine digital tools with analog instruments like, e.g., notebooks, pencils, and physical dice.[^fn10]  

# 4. Elements of a Short History of the Character Keeper #

<span class="paranum">[4.1]</span> Tracing the history of the tools used for online TRPG play in 2021 is not a straightforward endeavor. In the 2010s, the rise of Google Plus (a social network operated by Google from 2011 to 2019) as a significant communication platform for (indie) TRPG players and designers accelerated an international exchange of tools and ideas. In the same year that Google Plus was launched, Google Hangouts became the first video call service that allowed free conference calls for more than two parties, leading to widespread adoption of the service for online TRPG play. Together, the existence of Google Plus as a common communication platform (later supplemented by other chat tools like Slack) and Google Hangouts as a free play arena suggested (at least to some groups) to also use Google Docs, a collaborative online word processor, for keeping shared text documents. These first documents were often just notes on a play session or ongoing campaign. The exchange of players between gaming groups (facilitated by the new possibilities of online play) and discussions on Google Plus on how to keep such notes led to the emergence and diffusion of early forms of 'best practices.'  


<span class="paranum">[4.2]</span> While it seemed logical to share common information on setting and play history among the group, in the beginning, there was some hesitation in transferring character details to a shared document, as the paper character sheet was somehow considered 'sacred.' As the master record of a particular character, it firmly remained under the control of the respective player. For example, it seemed that any volatile information like hit points needed to be closely tracked on one original source that only one player could edit. But character information slowly crept into the collaborative session notes, as it was very convenient to use this shared document as a central player-facing resource during gameplay.  


<span class="paranum">[4.3]</span> Early attempts at creating what later became established as the format of the character keeper soon tried to replace paper character sheets fully. The availability of Google Sheets as free software accelerated this development. Since many players already had a Google account to play online via Google Hangouts, additional Google apps were often an obvious choice. They became the standard for sharing TRPG notes and finally for creating character keepers.  


<span class="paranum">[4.4]</span> Some of the oldest Google Sheets templates that could be called 'character keepers' in the sense that we discuss here probably were the ones designed by Shawn McCarthy back in 2013. McCarthy seems to have created the first keeper on June 11, 2013 for a very popular TRPG at the time, *Dungeon World* -- an indie take on *D&D*. In addition to a simple tab with the information for all characters, this keeper provides a "GM Summary," where the most important volatile information (Armor, Hit Points, Conditions) is collected.[^fn11] Another one is a simple single-tab spreadsheet that includes all necessary character information for *Fate Core* [@donoghue.etal2013]. McCarthy also added keepers for *Apocalypse World* and *Monsterhearts* [@alder2012], as well as *Mouse Guard* [@crane.petersen2008] and *The Quiet Year *[@alder2013] -- which also used other Google apps like Drawings and Slides. Reflecting on designing these early character keepers, he said in February 2021:  


<span class="paranum">[4.5]</span> > I wanted to avoid imposing on players to create & manage their own sheets elsewhere, help out the other GMs, and something puredeadsimple to get everybody's info in one place for my selfish sanity.  
> > I built out the original Dungeon World sheet well early 2013, based on the file info, and then started forking it […]. 
> > I took inspiration from the trifold AW [*Apocalypse World*] playbooks, and tried to keep it as close to those and as flexible as possible. (Shawn McCarthy 2021, personal correspondence)  


<span class="paranum">[4.6]</span> The concept quickly spread through the part of the indie TRPG community, which played online.[^fn12] At the same time, other local scenes experimented with using Google's apps for playing online. The German TRPG community on Google Plus, for example, started exploring possibilities to track and store character information in collaborative online docs, as we will see in the next section.  


<span class="paranum">[4.7]</span> In December 2015, Jason Cordova created a folder on Google Drive to collect character keepers and other templates ("Play Aids") that were used by the online TRPG community "The Gauntlet." The Gauntlet Play Aids Folder, as it now is referred to, has since grown into the largest free online play resource for indie TRPGs, collecting character keepers for over 400 games as of June 2021.[^fn13]  


<span class="paranum">[4.8]</span> Over the next few years, character keepers became a staple for online play in various indie TRPG communities.[^fn14] The Gauntlet published several blog posts providing an introduction to the format and various design tips [@barford2019a; @barford2019b; @barford2019c], attempting to initiate a larger conversation about the advantages of the form and common challenges in creating keepers. Keepers also showed up as part of games released through the indie marketplace itch.io. In 2019, they started to be used for online LARPs (or LAOGs, Live-Action Online Games) as well.  


<span class="paranum">[4.9]</span> In 2020, online TRPG play became much more prevalent, primarily because of the COVID-19 pandemic. More and more games, particularly in various indie TRPG communities, are now run using character keepers.[^fn15] In mid-2020, the character keepers for *Trophy Dark* [@ross2018] and *Trophy Gold* [@ross2019] that Drew Doucet created probably were the first keepers built 'professionally' as paid design work. Currently, new keepers seem to appear almost every day, both around the indie TRPG spaces somehow connected to The Gauntlet, which popularized the format, and in adjacent, unconnected spaces.[^fn16]  


<span class="paranum">[4.10]</span> In parallel to this history of the development of the character keeper format since the early 2010s, which we can only roughly sketch here, equipment for audio and video conferences was becoming more widespread among TRPG players, and online play in itself became more popular. With the rise of Actual Plays (the recording or live streaming of TRPG sessions for public consumption), playing TRPGs online and the resulting aesthetics of such sessions were normalized for a new generation of role-players as well as for long-standing members of the community who moved some or much of their play online. Recording a session was simple, for example, due to Google's Hangouts On Air service, which allowed easy recording of a Hangouts call to a YouTube channel. All of this contributed to the success of the digital character keeper as a decisively digital TRPG play aid.  


# 5. Glimpses of Exemplary Historical and Contemporary Character Keepers #

<span class="paranum">[5.1]</span> Analyzing historical and contemporary character keepers as prototypical examples can demonstrate their evolution and current role in the indie TRPG community. It highlights keepers' tangible impact on play culture and the performative 'role-playing text' [@stenros2004] that emerges during the session.  


<span class="paranum">[5.2]</span> One of the oldest proto-keepers was used in a campaign one of the authors of this article (G. Reininghaus) played in (see fig. 2). Created in 2012, it is in German and started as a session diary for a long-running online campaign (over twenty sessions) set in Aventurien, the fantasy world of the classical German TRPG *Das Schwarze Auge* ["The Black Eye," @kiesow1984]. However, the gaming group actually used the rules of *Savage Worlds* [@hensley2003], a semi-traditional universal TRPG system in the style of 1990s point-based-character-creation games.  


<span class="paranum">[5.3]</span> This Google Docs document, a precursor in spirit to the later Google Sheets character keepers, contains only a small portion of the actual character sheets that were still mostly kept in paper form next to the computer. The document lists so-called "hindrances" ("Handicaps" in the German translation of *Savage Worlds*), character flaws that all players can 'play against' to bring them into the narrative. The player whose character's hindrances become relevant in the fiction can earn a game resource called "benny." For that reason, the group considered it essential to have at least this information at everybody's disposal.  

![**Fig. 2: "Notes on 'By their own grace'," Screenshot from the 2012 Google Doc listing the "Handicaps" for the characters of a ****_Savage Worlds_**** campaign.**][JARPS_2_charakeepers-3]


<span class="paranum">[5.4]</span> A model for a whole generation of keepers was the 2013 template for *Dungeon World* already mentioned in section 3. This keeper uses a one-column-per-character structure that produces a very spreadsheet-like look which many later keepers also adopted (see fig. 3). The top row (using colors to distinguish the characters) is fixed to keep the character's name visible when scrolling. The "Notes" function is used to provide rules information like how to calculate the maximum hit points for a character.[^fn17] This keeper is still very basic but already uses some automation like calculating modifiers from the character's stats (entered manually) and summing up experience points. It also contains a second tab for the GM with basic stable and volatile character information. In mid-2016, Rich Rogers created an updated version of this keeper, which included auto-populating fields for the basic playbook moves.[^fn18]  

![**Fig. 3: Screenshot of a detail of McCarthy's 2013 keeper for ****_Dungeon World_****.**][JARPS_2_charakeepers-4]



<span class="paranum">[5.5]</span> In a 2015 keeper for *Monsterhearts*,[^fn19] another Powered by the Apocalypse (PbtA) game[^fn20] about teenage monsters and paranormal romance, the *Dungeon World* keeper's structure and design are still visible. This document, created by Jason Cordova, is clearly based on McCarthy's original 2013 template for *Monsterhearts* (a fork of the *Dungeon World* keeper) but has been updated with additional functionality. The character tab is still very basic but now uses drop-down menus to choose the values of the four stats and track harm and experience (see fig. 4). The possible values for the stats are drawn from a separate "DATA" tab (a typical structure for spreadsheet applications). Such pre-populated menus help players in following the rules or provide inspiration during character creation. Later keepers, like the updated *Dungeon World* one mentioned above, then use programmed formulas to pull in more complex information (like the rules text for specific character abilities) or automatically calculate some values depending on the entries in other fields. A second tab in the *Monsterhearts* keeper (already present in the 2013 version) visualizes an American high school classroom that represents the starting situation of the game. During play, it is used to track player characters, information on non-player characters, and relationships. A third tab ("Misc") invites players to add additional notes (for example, on what they want to see and don't see in the game, an early informal safety tool).  

![**Fig. 4: Screenshot of the drop-down menu in a 2015 keeper for ****_Monsterhearts_****.**][JARPS_2_charakeepers-5]


<span class="paranum">[5.6]</span> Many (especially newer) keepers contain a separate tab for safety tools. The Gauntlet Play Aids folder offers a standard, accessibly designed template for the tool "Lines & Veils," which allows players to select topics they want to avoid completely ("Line") or wish not to be played out in detail ("Veil").[^fn21] The template can be used as a standalone sheet or can be copied into an existing keeper (see fig. 5). Checkboxes allow players to indicate their preferences on how to treat particular topics, which are then highlighted in the color of the most restrictive column selected. Other keepers include additional safety tools like the X-Card or Script Change.[^fn22]  

![**Fig. 5: Screenshot of The Gauntlet's 2020 "Lines & Veils" template, optimized for legibility for vision-impaired people.**][JARPS_2_charakeepers-6]

<span class="paranum">[5.7]</span> Some keepers offer separate tabs to store additional information about the collaboratively created game world. Often, players and GM jointly enter these details, i.e., it is expected that everybody adds images, expands on details, and updates the information, etc. In the keeper for *BALIKBAYAN: Returning Home* [@nedjadi2019], for example, each player creates two NPCs connected to their PC with an image, name, pronouns, and a short descriptive text (see fig. 6).  

![**Fig. 6: Screenshot of the NPC tab of a 2019 keeper used for a session of ****_BALIKBAYAN: Returning Home_**** (images replaced with free to use alternatives from Pixabay.com).**][JARPS_2_charakeepers-7]

<span class="paranum">[5.8]</span> While Google Sheets has become the de-facto standard application for character keeper development and many newer examples continue to iterate on existing designs, there is a parallel history of using other tools for similar purposes in the second half of the 2010s.  


<span class="paranum">[5.9]</span> An example from early 2015 that uses Google Drawings is the keeper for the *Fate Core* setting *Save Game* [@wieland2014]. It is probably one of the first that includes the rules text for core mechanics, allowing play without (constantly) referencing the rulebook (see fig. 7). It is also an early example of a visual design that tries to reflect the setting's atmosphere. As the game is about old-school video games, mechanics are represented by coins, diamonds, hearts, and stars -- evoking resources from platformers like *Super Mario Bros*. [@miyamoto1985].  

![**Fig. 7: Screenshot of the 2015 keeper for a German-language session of ****_Save Game_****.**][JARPS_2_charakeepers-8]

<span class="paranum">[5.10]</span> Other keepers around 2015, especially for rules-light systems like *Cthulhu Dark* [@walmsley2010], also included much of the mechanical information necessary to play the game, with later and especially some of the most recent keepers featuring multiple tabs with reference information on mechanics, even for more complex indie TRPGs like the recently released *The Between* [@cordova2021; fig. 8].[^fn23]  

![**Fig. 8: Screenshot of the 2021 keeper for ****_The Between_****.**][JARPS_2_charakeepers-9]

<span class="paranum">[5.11]</span> Despite many advances, in the keeper for *Trophy Gold *from 2021[^fn24] the structure of the 2013 *Dungeon World *template can still be identified. Including decorations like the game's logo on a dedicated front page and adopting some of the color schemes of the published text, this professionally designed keeper -- its creation was a paid effort by the publisher to make online play easier -- features a formula-controlled tutorial which provides a step-by-step guide through the character creation process. There are tabs for additional character information, a bestiary (a particular mechanical aspect of *Trophy Gold*), and a data tab with a long list of names, inspiration for character backgrounds, and starting equipment (fig. 9). Incidentally, the official PDF character sheet for the sister game *Trophy Dark *(fig. 10), a column-based layout, was partly based on the aesthetic of character keepers, taking a future conversion to Google Sheets into account during the sheet's design (Jesse Ross 2021, personal correspondence).

![**Fig. 9: Screenshot of the official 2021 keeper for ****_Trophy Gold_****.**][JARPS_2_charakeepers-10]

![**Fig. 10: The column-based layout of the official ****_Trophy Dark_**** character sheet. **][JARPS_2_charakeepers-11]

<span class="paranum">[5.12]</span> Character keepers also can take on a much more central role in game design. The keeper for *World of Aventurien: Liska Hack* [a hack of *World of Dungeons*, @harper2012,  created by G. Reininghaus in -@reininghaus2019b] was built to run one specific *Das Schwarze Auge* module, In *Liskas Fängen* [@hlawatsch1995].[^fn25] The game was developed entirely in the keeper and does not exist outside of it. Moreover, the players contributed to its final shape as the game rules were adapted during the playtests. Some games even use character keepers to implement mechanics that would require complex technological solutions to reproduce them offline. The keeper for the Live Action Online Game (LAOG) *Outscored* [@reininghaus2019a, fig. 11][^fn26] uses conditional formatting to color each player's screen depending on their character's "social score" -- which changes depending on their actions in the game. As there is a rule that the only light illuminating the players' faces in the video call should be the light emitted by the monitor, this creates a direct link between the features of the keeper and the atmosphere of the game.  

![**Fig. 11: Screenshot of the 2019 keeper for ****_Outscored_****.**][JARPS_2_charakeepers-12]

# 6. What Makes Character Keepers Popular? -- Player and Designer Theorizing in the Contemporary Indie TRPG Scene #

<span class="paranum">[6.1]</span> Debates about character keepers among designers, GMs, and players are taking place at the (virtual) table during and around game sessions, but also in blog posts and online forums, on podcasts, and in actual play videos. Analyzing this material demonstrates how users reflect on the development of character keepers, the practices of using them for playing online, and their various roles in gameplay.  


<span class="paranum">[6.2]</span> Player theorizing is an important aspect of the culture of role-playing games. As Torner [-@torner2018a] highlighted, players' and designers' "para-academic" theories have contributed significantly to TRPG discourse. Historically, the line between players, designers, and what Torner [-@torner2018a, 192, drawing on @hills2002] calls "aca-fans" -- academics who are both fans and scholars of TRPGs -- has been blurry, and much of what once started as player theorizing found its way into academic theory. In a certain sense, then, the reflections we present here are at times little more than a systematization of these discussions within the contemporary indie TRPG scene.  


<span class="paranum">[6.3]</span> Most player and designer theorizing on character keepers -- as a "killer app in online play" [@beakley2021] -- focuses on aspects that appear as directly beneficial to either the *gameplay* or the *design* of TRPGs. The following quote from Rich Rogers represents the gameplay aspect well. He describes his fondness for character keepers on the podcast *Diceology* in these words:  


<span class="paranum">[6.4]</span> > The thing is, it really is an evolutionary step in how we […], at least in most games, […] look at our characters and how other people look at their characters. And I don't know if it is super valuable to have a character keeper for a game like, say a D&D-type game, you know, something where you're a little bit your own island, but in games where there is a lot more collaboration, […] where you may have certain moves that other people can set up, it is so powerful just to look across that array and just see everybody's stuff, their hooks, what they're about, see cool pictures of them, is so so helpful. It is awesome. I love character keepers, like, I can't get away from them. I wish there was a way to do it at the physical table, you know, where you just like have a tablet or something. It's great. [@brown.rogers2020, 03:22-04:18]  


<span class="paranum">[6.5]</span> He highlights the support keepers provide for collaboration at the table and how they facilitate aspects of gameplay that go beyond what is easily possible with analog tools. Jamila Nedjadi emphasizes the role of keepers in game design and playtesting:  


<span class="paranum">[6.6]</span> > I use a Character Keeper to design the game. It used to be that I would write/design the game while laying out the game at the same time, but doing that and then transferring everything to a Character Keeper took up so much time and energy.  
> > Because I'm designing directly into a Character Keeper now, it's much easier to playtest and make changes as we playtest a game. I've been doing this for more than 6 months now and it's a system that works for me! (2021, personal correspondence)


<span class="paranum">[6.7]</span> Moe Poplar discusses his use of character keepers in game design on the podcast *+1 Forward*:  


<span class="paranum">[6.8]</span> > [C]haracter keepers have become kind of one of my main development tools lately. […] I'm currently working on a game *Holdfast Outpost*. And we've done so much design in our character keeper, we just realized it's got to be challenging actually making character sheets, because they're just flat. But my favorite thing about character keepers is […] they're free. They really democratize the gaming space. […] [Y]ou sign up for a Google account […], learn a little bit Excel and start building character keepers. Make them do what you want to do. [@shelkey.etal2021, 01:31-06:53]  


<span class="paranum">[6.9]</span> Both Nedjadi and Poplar focus on the advantages keepers provide for playtesting, their easy availability, and their versatility as a tool for game design.  


<span class="paranum">[6.10]</span> Starting from these more general reflections, the discussion about character keepers can be systematized according to the different 'frames' of TRPG play. Frame analysis in the tradition of sociologist Erving Goffman [-@goffman1974] has been a prominent analytical perspective in role-playing game studies, building on Fine's [-@fine1983] and Mackay's [-@mackay2001] pioneering work. We follow Grouling Cover [@cover2010, 89] in distinguishing between the *social frame* of player interaction, the *game frame* of play, and the *narrative frame* of the fictional world [see also @hedge2021, 62-66; @friedman2021, 190-91]. Slightly adapting a typology proposed by Mackay [-@mackay2001, 56], the people at the table are addressed as *persons* in the social frame, as *players* in the game frame, and as their *characters* in the fictional world in the narrative frame.  


<span class="paranum">[6.11]</span> Regarding the *social frame*, an often-mentioned advantage of using a character keeper is *organizational*. Due to being on Google Sheets, keepers are described as easy to access without installing additional software or creating accounts [players do not even need a Google account to use a keeper; @barford2019a; @gurantz.astadan2021, 05:15-05:27]. In addition to being simple repositories of character information, more complex keepers can be considered full "campaign managers, with tabs for every kind of data you could imagine: NPCs, locations, timelines, whatever" [@beakley2020]. Collecting all important play information and organizing it neatly, they serve as a shared source of truth about the characters and the fictional world.  


<span class="paranum">[6.12]</span> Keepers also help manage expectations and relationships between players, an additional aspect of the social frame, in particular by making it easy to use *safety tools* in online play. Especially in the indie TRPG scene, their use has become popular [see the *TTRPG Safety Toolkit*, @shaw.bryant-monk2019]. Many character keepers include separate tabs for this, as Poplar highlights:  


<span class="paranum">[6.13]</span> > I love how you can manage safety. There's an opportunity with character keepers to give everybody a dashboard. And they then have a way to communicate with a GM if you configure it such. And so X-Card [a way to signal that the topic currently in play should be avoided] becomes something that is anonymous and effective […]. [@shelkey.etal2021, 04:15-04:31]  


<span class="paranum">[6.14]</span> Using programming functions can also make safety tools easy to use by automatically highlighting selected options [@gurantz.astadan2021, 48:05-48:39]. Similarly, using a keeper might make it easier to remember everyone's names and preferred pronouns [@barford2019a], an advantage, especially when playing online with strangers.  


<span class="paranum">[6.15]</span> If we look at the *game frame*, a large variety of different aspects are discussed when expressing how keepers support play. Probably the most often mentioned "unique advantage of online character keepers" [@barford2019b] is that *having shared access to the information for all players' characters* (possibly even on the same spreadsheet tab) facilitates collaborative play [@barford2019b; @beakley2021]-- as stressed by Rogers in the first quote at the beginning of this section. Being aware of all characters' backgrounds, 'drives,' or 'bonds' makes it easier to incorporate these elements into the narrative. This awareness, however, could also lead to problematic forms of optimization, as one GM reports about his first experience of using a character keeper: "since everyone can see everyone's sheet, we have a tendency to drop into 'who would be best at this thing?'" [@durrell2020].  


<span class="paranum">[6.16]</span> A second advantage often mentioned that relates to the game frame is the possibilities afforded by *automation*, something common to digital character sheets and an important feature of keepers compared to paper sheets. Rogers, for example, highlights automation's various possibilities:  


<span class="paranum">[6.17]</span> > [M]y mind buzzes, like oh, you know, we could do a drop down, that like pops in this other stuff, and then auto calc this. And then I was like, oh wait, if you have a formula that will show an image, then you could have a drop down and then pop in the image of what the thing that you selected in your equipment looks like. [@brown.rogers2020, 04:55-05:14]  


<span class="paranum">[6.18]</span> At the same time, he cautions that too much automation might make things too complicated for players [@brown.rogers2020, 05:20-05:27; see also @shelkey.etal2021, 09:59-10:09]. He points out that designing a keeper [like designing a paper sheet; see @morningstar2016] is always a question of accounting for the concrete user experience. Still, according to Poplar, keepers can make complex systems easy to handle:  


<span class="paranum">[6.19]</span> > I like how you can use character keepers to manage mechanics, you can automate the stuff that normally has to be bookkeeping or crutch at the table. If you have a game where increasing strength makes you more tough and resilient, you can actually let the character keeper do all the work. If getting hurt affects your dice pool or your pluses to your rolls. You can also let the character keeper reflect that. So it takes all the crunchy bits off of the player's shoulders. [@shelkey.etal2021, 03:36-04:04]  


<span class="paranum">[6.20]</span> Helping players deal with some of the mechanical crunch of playing a TRPG is something digital character sheets on VTTs can also provide. Nevertheless, designers often mention the ease with which Google Sheets makes such forms of automation possible even for complex mechanical aspects of a system. For example, in the official keeper for the recently released *The Between*, the mechanical aspects of certain moves and some game elements like the switching between phases of play are programmed into the keeper so that players don't need to track them separately or consult the rule book [@cordova2021a; @cordova2021b].  


<span class="paranum">[6.21]</span> A third advantage often mentioned is how character keepers help "streamline and simplify" [@barford2019a] the *creation of characters*. According to Tomer Gurantz, a well-organized keeper allows you to "easily go through this thing from top to bottom […] and just create your character" [@gurantz.astadan2021, 04:29-04:34]. One recent trend is to combine this with automation and support, walking players through character creation step-by-step [see @cordova2021c]. Keepers are thus described as helping to "reduce manual input of character info to increase the ease-of-use […] and decrease the length of character creation" [@barford2019c].[^fn27] In addition, this reduction of the need to refer to the rulebook does not only make character creation easier but also extends to the rest of the session, as some keepers incorporate all rules needed for play (at least on the players' side), as in the case of the keeper for *The Between* [@cordova2021d].  


<span class="paranum">[6.22]</span> Such advantages regarding gameplay (e.g., drop-downs for the selection of character options, Donogh McCarthy 2021, personal correspondence) are also often discussed as helping people *learn the game* in the first place, as keepers highlight the elements that players need to focus on [@gurantz.astadan2021, 04:34-04:53]. In addition, their creation and design are also described as a good way of learning how to *run* a game:  


<span class="paranum">[6.23]</span> > I used to always do up a short cheat sheet of any new game I was about to run, as a way to learn and solidify the system. Creating a character keeper serves a similar function in my brain, with the added challenge of information design: should I put the "important" stuff higher, and what's "important" anyway? How do I group related details? What elements can I leave off the keeper? What can I automate and how does the math actually work? Can I pretty it up without making it distracting? [@beakley2020]  


<span class="paranum">[6.24]</span> In the same vein, creating a keeper might help a GM better understand what parts of a system players have to know about during a session [@barford2019b]. This is described as very useful, especially in the indie TRPG community, where it is customary to play many different games over a short period of time. Similarly, keepers are seen as *helping GMs prepare for a game session*:  


<span class="paranum">[6.25]</span> > I go through to look at the keeper for particular hooks: entanglements, NPCs, aspects -- all those things which tell me what the player wants. I'll also look at their abilities to see which they've taken and maybe haven't used as much -- then I try to create situations playing to those at the table. The biggest help is keeping an NPC tab in the keeper to remind me of the cast of characters. (Lowell Francis 2021, personal correspondence)  


<span class="paranum">[6.26]</span> How a well-built and organized keeper allows an excellent overview over all important aspects of an ongoing series of sessions, GMs argue, makes it an ideal tool for preparation.  


<span class="paranum">[6.27]</span> An interesting additional aspect related to the game frame is the question of *dice rolling*. While a variety of methods for including random number generation and dice rolling into character keepers have been proposed and tried out, most of these methods either do not work, only work some of the time, or are cumbersome to use [@brown.rogers2020, 5:30-6:45; @harvey.etal2021, 19:54-21:57]. Here, the needs of the TRPG community and the needs for the majority of Google Sheets users are not aligned -- the software is not made for TRPGs but is primarily oriented towards other use cases.  


<span class="paranum">[6.28]</span> Concerning the *narrative frame* and the *collaborative creation of the fictional world* through the conversation at the table, character keepers are seen as helping create a story in which each of the player characters' special abilities and other narrative elements are regularly incorporated. From the GM's side, Rogers describes this as follows when reflecting on how a return to playing around a physical table after the COVID-19 pandemic might mean abandoning the use of keepers:  


<span class="paranum">[6.29]</span> > I see everybody's moves all on one part of the sheet, one tab. And I can just look and oh, man, I see this conversation. I can point *this* towards *that* person's moves that they haven't triggered in a while. [...] Man, that is some tech that I'm gonna miss at a physical table big time. It has really helped me step up my game to make sure that I'm […] looking at what playbooks are driven to do. [@shelkey.etal2021a, 28:12-28:43, emphasis added by the authors]  


<span class="paranum">[6.30]</span> As he describes it, keepers play a role in connecting the game frame and the narrative frame, providing inspiration and prompts for GMs and players on where to take the narrative next. For Greg Gelder, this relates to a general function of character sheets, reinforced by the shared nature of the character keeper:  


<span class="paranum">[6.31]</span> > Character sheets are a form of communication, a communication about what you want to see in play. And having them all together, as opposed to you looking at your own communication to yourself about what you want to do, having them all together in a character keeper, it allows other players to be like, "Oh, so you're a fighter. But you've taken all of these choices about working things out before you fight […]". […] [Y]ou can engage with another player and say, "Oh, we should have a scene where we get together over here and really hit those keys that you've been trying to hit." [@nedjadi.etal2021, 01:05:59-01:06:47].  


<span class="paranum">[6.32]</span> In this way, the information in a keeper can directly lead to a player or GM framing a particular scene or taking the narrative into a direction that resonates with one or more of the characters' backgrounds or abilities, which helps to "make the ecosystem of the game immediate and present during play" (Donogh McCarthy 2021, personal correspondence). While in many traditional TRPGs, narrative speech is "most often spoken by the DM" [@cover2010, 103], many indie TRPGs offer plenty of opportunities for players to take on the role of a narrator of events, proposing and setting up scenes for their own and other characters, which, as is argued by Rogers and Gelder above, is facilitated by the use of a character keeper.  


<span class="paranum">[6.33]</span> The role of (the creation of) keepers in learning how to play and run a particular game points to an additional important aspect of the contemporary debate that goes beyond play at the table: the *design of character keepers* and their *role in game design* more generally [@barford2019b].[^fn28]  


<span class="paranum">[6.34]</span> Designing a keeper, Donogh McCarthy notes (2021, personal correspondence), involves at minimum figuring out "what the player should have to play their character," "what might be useful to have during character generation," and finally, "what might be key for the other players to see about them." As we have already seen, in most cases, one of the fundamental design decisions is putting all characters in columns on a single tab or having a separate tab for each one. Lowell Francis proposes the former:  


<span class="paranum">[6.35]</span> > I generally use single columns on one shared sheet with each one for a character. I tried having characters on individual tabs, but that loses the ability for everyone to see each other's characters. So even for more info heavy games, I keep them on the same tab.  
> > Identity goes at the top, sometimes I lock that so the character's name is visible even if you scroll down. The next most important element are whatever stats or values the majority of rolls will be based on these should be large and legible. Everything else follows from there. (2021, personal correspondence)  


<span class="paranum">[6.36]</span> In contrast, Nedjadi describes how for them, the choice for a single or multi-tab layout depends on the concrete mechanical nature of the particular system:  


<span class="paranum">[6.37]</span> > If a game has a lot of mechanics for teamwork or keeping track of everyone's resources/abilities is important, I put all the Characters in one sheet.  
> > But if a game has a lot of information to keep track of (long Moves for example), and it would mean scrolling down a lot and losing track of all your options, each character gets their own sheet instead. (2021, personal correspondence)  


<span class="paranum">[6.38]</span> The design approach can also vary depending on whether a keeper is designed primarily for one-shot play or for running longer campaigns -- which, for example, influences whether options for character advancement have to be included (Francis 2021, personal correspondence). Another important question is the visual design of the keeper, like the use of particular fonts to "communicate the feel of the game" (Nedjadi 2021, personal correspondence).  


<span class="paranum">[6.39]</span> It is important to note that the practice of character keeper design often involves copying an existing keeper and working off of this template by revising and reworking it according to the needs of a particular game. In this sense, today's character keepers, in particular many of the most popular ones, are the result of a very complex process of borrowing and cross-pollination between a sizeable number of players, GMs, and game designers [see @shelkey.etal2021, 08:21-09:49]. Sometimes certain innovations or concerns (e.g., 'freezing' in place the top rows with basic information like character names to be always visible, separate fields for player and character pronouns, or a tab for safety tools) are picked up quickly by other designers and spread among different keepers. In contrast, at other times, new or experimental additions stay limited to only a few keepers (e.g., complex solutions for random number generation or, at least until now, most attempts at accessible design).  


<span class="paranum">[6.40]</span> Most keepers are still the product of players and GMs who create them ad-hoc, according to their specific needs. Still, the role of the keeper creator might become more professionalized in the next few years, as recently several professionally developed keepers have been designed, particularly for games released by Gauntlet Publishing. In any case, the character keeper designer is now a new role (and new skillset) that designers and producers of indie TRPGs could take on themselves or consider budgeting for, as a game is more likely to be picked up by online TRPG players when a keeper is readily available.  


<span class="paranum">[6.41]</span> The second design-related issue regarding character keepers is, as described at the beginning of this section by Nedjadi and Poplar, the use of character keepers and keeper design as a tool for designing the game itself. As a potentially complete repository of all the important elements of a game, playtesting and revising a game during the design phase can be significantly facilitated by 'designing in the keeper.' Francis (2021, personal correspondence) describes this process during the design of *Hearts of Wulin* [@francis2021] as follows: "I sketched things out, built a keeper, and then used that to figure out what else I needed and to see all the elements in parallel." Another often-mentioned aspect is that quickly designing a hack of a particular game and having it ready for a playtest is made easier by using a character keeper. Over the last years, Rich Rogers (2021, personal correspondence), for example, created a variety of hacks for existing TRPGs, reworking them for the Star Wars universe. Many of these games only exist within their particular character keeper.[^fn29]  


# 7. Conclusion #

<span class="paranum">[7.1]</span> This article has attempted to provide an overview of the emergence and contemporary use of character keepers as digital play aids in the indie TRPG community. At the same time, analyzing their actual effects on play culture is hardly possible by studying keepers in isolation outside of actual play. In this sense, while we hopefully were able to provide a detailed overview of the characteristics of character keepers, many of the concrete ways that their affordances affect play culture can only really be studied by observing gaming as an activity [@stenros.waern2011]. Therefore, we suggest that future research should be concerned with the wide variety of ways in which character keepers are used during concrete gaming sessions. The rise in online TRPG play, which their emergence is a part of, contributes to the realization that these games have always been a multimodal and transmedial phenomenon [@hedge.grouling2021a, 8–10]. At the same time, the broad success of recording actual play TRPG sessions both as professional entertainment productions and amateur endeavors provides a much broader empirical basis for studying their play cultures than has ever been available before.[^fn30] Research into digital play aids and TRPG online play more generally is really just beginning.  


# Ludography  #

<span class="paranum">[8.1]</span> 

[JARPS_2_charakeepers-1]: JARPS_2_charakeepers-1.png {width=1734 height=1484}

[JARPS_2_charakeepers-2]: JARPS_2_charakeepers-2.png {width=1734 height=1484}

[JARPS_2_charakeepers-3]: JARPS_2_charakeepers-3.png {width=938 height=704}

[JARPS_2_charakeepers-4]: JARPS_2_charakeepers-4.png {width=842 height=553}

[JARPS_2_charakeepers-5]: JARPS_2_charakeepers-5.png {width=580 height=551}

[JARPS_2_charakeepers-6]: JARPS_2_charakeepers-6.png {width=1318 height=853}

[JARPS_2_charakeepers-7]: JARPS_2_charakeepers-7.png {width=962 height=597}

[JARPS_2_charakeepers-8]: JARPS_2_charakeepers-8.png

[JARPS_2_charakeepers-9]: JARPS_2_charakeepers-9.png {width=1574 height=459}

[JARPS_2_charakeepers-10]: JARPS_2_charakeepers-10.png {width=841 height=666}

[JARPS_2_charakeepers-11]: JARPS_2_charakeepers-11.png {width=336 height=851}

[JARPS_2_charakeepers-12]: JARPS_2_charakeepers-12.png {width=911 height=496}

[^fn1]: Many thanks to the two anonymous reviewers for their suggestions and especially to all the people from the indie TRPG community who have talked with us about character keepers in the last few months, in particular Michael G. Barford, Jason Cordova, Drew Doucet, Lowell Francis, Bethany Harvey, Donough McCarthy, Shawn McCarthy, Jamila Nedjadi, Rich Rogers, Jesse Ross, and Evan Torner.

[^fn2]: According to Hammer, regarding TRPGs it is helpful to distinguish three forms of texts: "The primary text is that which outlines the rules and setting of the game in general. The secondary text uses this material to create a specific situation. Finally, the tertiary text is created as the characters encounter the situation in play" [@hammer2007, 70-71].

[^fn3]: In 1979, in an interesting early case of attempting to create a different play culture, Greg Stafford published "play aids" for a scenario for *RuneQuest* [@perrin.stafford1978] that included "a sheet of common knowledge" [@stafford1979, 11, 10] with shared information that the player characters had about each other [see @peterson2020, 155-56].

[^fn4]: There is a history to be written of the various forms of digital character sheets that were offered over time for larger systems like *D&D* (from the *e-Tools* offered with the 3rd edition's *Player's Handbook* to *D&D Insider* [see @mizer2019, 42-43] and today's *D&D Beyond*) and that have been developed for Virtual Table Tops (VTTs) like Fantasy Grounds and Roll20. The latter, probably the biggest VTT today, did not include character sheets when it launched in September 2012 [see @roll202012]. Sheets were first added in April 2014. The blog post announcing the new feature clearly indicates that the developers expected people to be playing using paper sheets when using Roll20 until the introduction of this update [@roll202014]. This example shows that research into the history of digital character sheets and their role in playing TRPGs online is only beginning. For example, the open-source VTT MapTool, first released in 2006, included support for the creation of digital character sheets early on. On VTTs and Roll20, see also the chapters in part II in @hedge.grouling2021.
	  The term "character keeper" for this form of digital character sheet was coined by Jason Cordova, probably in 2015 or 2016 (Jason Cordova 2021, personal correspondence).

[^fn5]: The term "character keeper" for this form of digital character sheet was coined by Jason Cordova, probably in 2015 or 2016 (Jason Cordova 2021, personal correspondence).

[^fn6]: There is a parallel history of using Google Sheets for character records for mainstream TRPGs like *D&D* (going back to at least July 2014), which we will not be able to get into here. In contrast to character keepers, however, these sheets mainly were designed to be used (and possibly printed out) by only one player each, with players managing their own private sheet and possibly sharing it with the GM [for example, @kilnor2014; @tintagel2014].

[^fn7]: *Dungeon World*: [https://docs.google.com/spreadsheets/d/1phUTnmLblFl_fxjCbHiAkR3xmppfzpcNxNC4RDH9b9k/](https://docs.google.com/spreadsheets/d/1phUTnmLblFl_fxjCbHiAkR3xmppfzpcNxNC4RDH9b9k/) (accessed 2021/11/08); *Brindlewood Bay*: [https://arktosaur.us/keepers/brindlewoodbay](https://arktosaur.us/keepers/brindlewoodbay) (accessed 2021/11/08).

[^fn8]: On Roll20, for example, sheets can be shared and accessed by multiple players, but the most widespread way of playing still remains that every player only ever really accesses their own sheet. When introducing their newly added character sheets, the Roll20 team wrote: "Sheets look exactly like a paper sheet, including images, different types of fields (checkbox, text, number, drop-down selection, etc.), and a familiar layout. […] [They] match the 'official' sheet for each game system […]" [@roll202014].

[^fn9]: This Google Drive folder is part of the community resources of The Gauntlet ([https://www.gauntlet-rpg.com/community-resources.html](https://www.gauntlet-rpg.com/community-resources.html); accessed 2021/11/08) and can be found at: [http://tiny.cc/TheGauntletPlayAidsFolder](http://tiny.cc/TheGauntletPlayAidsFolder) (accessed 2021/11/08).

[^fn10]: On the multiple tools used in online play when using VTTs like Roll20, see Webb and Cesar [-@webb.cesar2019], Hedge [-@hedge2021], Roques [-@roques2021], as well as Lawson and Wigard [-@lawson.wigard2021].

[^fn11]: His announcement is still online [@mccarthy2013a], as is the folder with his templates [@mccarthy2013b]. There are some other even earlier Google Sheets templates designed for *Dungeon World*, for example, some of which could be considered early character keepers as well. While the sheet announced by Thorax [-@thorax2012a] offers similar functionalities as McCarthy's keeper, it does not use a single sheet for all characters [-@thorax2012b]. Others use different spreadsheet documents for each player [@convict2012]. We single out McCarthy's work here mostly because his creations put all characters on a single tab and were later copied and revised for many other games. The influence of his 2013 design is still visible today.

[^fn12]: A cursory look at other digital character sheets discussed or offered in online community spaces in the mid-2010s reveals that in parallel to the development of the character keeper format, other uses of Google Docs or Sheets also emerged, which stayed closer to the visual design of classical character sheets. See e.g., for *Dungeon World* the Google Plus threads Phips Peter [-@phips2014] and Griffin [-@griffin2015].

[^fn13]: The folder can be found at [http://tiny.cc/TheGauntletPlayAidsFolder](http://tiny.cc/TheGauntletPlayAidsFolder) (accessed 2021/11/08).

[^fn14]: t is difficult to trace these developments, as many of the discussions about character keepers in the second half of the 2010s took place either on Google Plus (which shut down in 2019 and has mostly not been archived) or in private chat groups like Slack community workspaces. Some glimpses can be found by searching for "character sheet," "character keeper," or "Google Sheets" on the archived Google Plus pages for some indie TRPG communities at [https://gplusarchive.online/](https://gplusarchive.online/) (accessed 2021/11/08).

[^fn15]: In October 2020, The Gauntlet community tried to promote keepers as an important aspect of its play culture in a blog post on running TRPGs online [@francis2020].

[^fn16]: One example would be the intricately designed 2020 character keepers for *Dungeon Crawl Classics* created by Tuirgin [-@tuirgin2020].

[^fn17]: According to Shawn McCarthy (2021, personal correspondence), the notes might have been added in a later revision (the file has a last modified date of 21 Nov 2013), which would make the forked sheets for *Apocalypse World* and *Monsterhearts* more representative of what the original sheets might have looked like (no calculations and automation).

[^fn18]: See @gauntlet2016, 07:11-09:03. "Moves," a PbtA concept (see footnote XXXXX), are (sometimes character-specific) 'abilities' that a character might use during the game. A further updated version of this sheet is still available in the current Gauntlet Play Aids folder: [https://docs.google.com/spreadsheets/d/1_HCsKmqlycAPbOEhcp3SGctZbQnpFhsB7opNUdhknhI/](https://docs.google.com/spreadsheets/d/1_HCsKmqlycAPbOEhcp3SGctZbQnpFhsB7opNUdhknhI/) (accessed 2021/11/08).

[^fn19]: This keeper is now available at: [https://docs.google.com/spreadsheets/d/1fYR74ncDjXNNcHJlw4uW0611BdMT7ub4a2Ww4wgpqZk/](https://docs.google.com/spreadsheets/d/1fYR74ncDjXNNcHJlw4uW0611BdMT7ub4a2Ww4wgpqZk/) (accessed 2021/11/08).

[^fn20]: Powered by the Apocalypse (PbtA) is a design framework for TRPGs that centers the conversation about the fictional world and the resolving of character actions through "Moves" triggered by the fictional situation, often resulting in complications that push the story forward [see @baker2019]. The name is a result of this basic structure having been developed for the game *Apocalypse World*.

[^fn21]: The template is available at: [https://docs.google.com/spreadsheets/d/1QM7-8d0QusVI1C-lGd9ZplO3s6Jgz_Puuwm8CFoErxM/](https://docs.google.com/spreadsheets/d/1QM7-8d0QusVI1C-lGd9ZplO3s6Jgz_Puuwm8CFoErxM/) (accessed 2021/11/08).

[^fn22]: See the *TTRPG Safety Toolkit* [@shaw.bryant-monk2019] for an introduction to various TRPG safety tools.

[^fn23]: Available at: [https://www.arktosaur.us/keepers/thebetween](https://www.arktosaur.us/keepers/thebetween) (accessed 2021/11/08).

[^fn24]: Available at: [https://www.arktosaur.us/keepers/trophygold](https://www.arktosaur.us/keepers/trophygold) (accessed 2021/11/08).

[^fn25]: Available at: [https://docs.google.com/spreadsheets/d/1NgewEMeoxn9mxQv1S2f4zhur6MtbB6hOv_5GVRmVOD8/](https://docs.google.com/spreadsheets/d/1NgewEMeoxn9mxQv1S2f4zhur6MtbB6hOv_5GVRmVOD8/) (accessed 2021/11/08).

[^fn26]: Available at: [https://docs.google.com/spreadsheets/d/1HP2WxmnfA2zRxCLXMtuOSw8tOWmpe9k6n2ck3KLTpds/](https://docs.google.com/spreadsheets/d/1HP2WxmnfA2zRxCLXMtuOSw8tOWmpe9k6n2ck3KLTpds/) (accessed 2021/11/08).

[^fn27]: It is interesting to note that character sheets that include tutorials for character creation already appeared in fanzines for *D&D* in the mid-1970s ([@peterson2013].

[^fn28]: Another aspect of the contemporary discussion, which we can't explore in detail, is promotions of the character keeper's format and general instructions on how to create keepers [@barford2019a; @barford2019b; @barford2019c; @gurantz.astadan2021; @harvey.etal2021].

[^fn29]: E.g., *Republic Rifles* ([(https://docs.google.com/spreadsheets/d/1vRXx5E2hhQ6AguQUzj5Ol2hrBr-uar1TIz520vupgwM/]((https://docs.google.com/spreadsheets/d/1vRXx5E2hhQ6AguQUzj5Ol2hrBr-uar1TIz520vupgwM/); accessed 2021/11/08) or *SWS: Neon City Overdrive*  ([https://docs.google.com/spreadsheets/d/1vT_4cL_V1RGR-Bbx34R9aGMeMMMnXiAeVYrve6-zDBA/](https://docs.google.com/spreadsheets/d/1vT_4cL_V1RGR-Bbx34R9aGMeMMMnXiAeVYrve6-zDBA/); accessed 2021/11/08).

[^fn30]: See also @jones2021. The Gauntlet community, in particular, has not only been at the center of the rise to prominence of the format of the character keeper. It has also collectively produced hundreds of actual play videos on a variety of YouTube channels, which could serve as the empirical material for this kind of study. They can be found at [https://www.youtube.com/TheGauntletRPG/playlists](https://www.youtube.com/TheGauntletRPG/playlists) (accessed 2021/11/08) and in podcast format at [http://gauntlet.hellomouth.net](http://gauntlet.hellomouth.net) (accessed 2021/11/08).